#!/usr/bin/env python

import sys
from PyQt4.QtCore import *
from PyQt4.QtGui import QMainWindow, QStackedLayout, QApplication, QWidget

from dm.common.constants import dmStatus
from dm.common.exceptions.dmException import DmException
from dm.common.exceptions.configurationError import ConfigurationError
from dm.common.utility.loggingManager import LoggingManager
from dm.common.utility.configurationManager import ConfigurationManager

from experimentsTab import ExperimentsTab
from daqsTab import DaqsTab
from uploadsTab import UploadsTab
from initialTab import InitialTab


class DmStationUi(QMainWindow):
    def __init__(self):
        self.__configure()
        self.logger.debug('Starting UI for DM Station: %s' % self.stationName)
        super(DmStationUi, self).__init__()

        self.setWindowTitle('DM Station: %s' % self.stationName)
        self.setGeometry(0, 0, 800, 400)
 
        # Create a stacked layout to connect the various pages
        self.stackedLayout = QStackedLayout()
 
        # Create the tab windows
        initialTab = InitialTab(self.stationName, self.stackedLayout)
        experimentsTab = ExperimentsTab(self.stationName, self.stackedLayout)
        #daqsTab = DaqsTab(self.stationName, self.stackedLayout)
        #uploadsTab = UploadsTab(self.stationName, self.stackedLayout)
 
        # Add the windows to the stack.
        self.stackedLayout.addWidget(initialTab)
        self.stackedLayout.addWidget(experimentsTab)
        #self.stackedLayout.addWidget(daqsTab)
        #self.stackedLayout.addWidget(uploadsTab)

        # Set a central widget to hold everything
        self.centralWidget = QWidget()
        self.centralWidget.setLayout(self.stackedLayout)
        self.setCentralWidget(self.centralWidget)

    def __configure(self):
        self.logger = LoggingManager.getInstance().getLogger(self.__class__.__name__)
        configManager = ConfigurationManager.getInstance()
        self.stationName = configManager.getInstance().getStationName()
        if not self.stationName:
            raise ConfigurationError('DM_STATION_NAME environment variable is not defined.')
 
if __name__ == "__main__":
    try:
        app = QApplication(sys.argv)
        DmStationUi().Show()
        app.MainLoop()
    except DmException, ex:
        print >>sys.stderr, 'ERROR: %s' % ex
        raise SystemExit(ex.getErrorCode())
    except Exception, ex:
        print >>sys.stderr, '%s' % ex
        raise SystemExit(dmStatus.DM_ERROR)
